/* LICENSE BLOCK
Part of mde: a Modular D game-oriented Engine
Copyright © 2007-2008 Diggory Hardy

This program is free software: you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation, either
version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>. */

/** Some GUI Miscelaneas widgets. */
module mde.gui.widget.miscWidgets;

import mde.gui.widget.AChildWidget;
import mde.gui.exception;
import mde.gui.renderer.IRenderer;
import mde.content.IContent;

import tango.util.log.Log : Log, Logger;

private Logger logger;
static this () {
    logger = Log.getLogger ("mde.gui.widget.miscWidgets");
}


/// A fixed-size blank widget.
class FixedBlankWidget : FixedWidget
{
    this (IWidgetManager mgr, IParentWidget parent, widgetID id, WidgetData data) {
        WDCheck (data, 3);
        super (mgr, parent, id, data);
    }
    
    override void draw () {
        super.draw;
        
        mgr.renderer.drawBlank (x,y, w,h);
    }
}

/// A completely resizable blank widget (initial size zero).
class SizableBlankWidget : SizableWidget
{
    this (IWidgetManager mgr, IParentWidget parent, widgetID id, WidgetData) {
        super (mgr, parent, id);
    }
    
    override void draw () {
        super.draw;
        
        mgr.renderer.drawBlank (x,y, w,h);
    }
}

/// A debug widget. Essentially as SizableBlankWidget but doesn't mind any amount of data and prints it.
class DebugWidget : SizableWidget
{
    this (IWidgetManager mgr, IParentWidget parent, widgetID id, WidgetData data, IContent c) {
        super (mgr, parent, id);
        logger.warn ("Debug widget ({}); parameters: ints = {}, strings = {}; content: {}", id, data.ints, data.strings, c);
    }
    
    override void setContent (IContent c) {
	logger.info ("Debug widget ({}); new content set: {}", c);
    }
    
    override void draw () {
        super.draw;
        
        mgr.renderer.drawBlank (x,y, w,h);
    }
}
